=======================
``psyclone.psyad.main``
=======================

.. automodule:: psyclone.psyad.main

   .. contents::
      :local:

.. currentmodule:: psyclone.psyad.main


Functions
=========

- :py:func:`main`:
  Takes an LFRic tangent linear kernel source file as input and


.. autofunction:: main
